@@ -178,7 +178,7 @@ SEXP deque_remove(SEXP self, SEXP value) {
 
 SEXP deque_clear(SEXP self) {
     set_sexp_value(self, "q", R_NilValue);
-    SEXP last = PROTECT(R_MakeExternalPtr(NULL, R_NilValue, R_NilValue));
+    SEXP last = PROTECT(R_MakeExternalPtr(0, R_NilValue, R_NilValue));
     set_sexp_value(self, "last", last);
     UNPROTECT(1);
     set_int_value(self, "n", 0);
